pub fn map_bar_spec_to_candle_width(
spec: &BarSpecification,
) -> Result<AxCandleWidth>Expand description
Maps a Nautilus [BarSpecification] to an AxCandleWidth.
Errors
Returns an error if the bar specification is not supported by Ax.
pub fn map_bar_spec_to_candle_width(
spec: &BarSpecification,
) -> Result<AxCandleWidth>Maps a Nautilus [BarSpecification] to an AxCandleWidth.
Returns an error if the bar specification is not supported by Ax.