pub fn cid_to_client_order_id(cid: u64) -> ClientOrderIdExpand description
Creates a [ClientOrderId] from a cid value.
Used when we receive an order with a cid but cannot resolve it to the original ClientOrderId (e.g., after restart when in-memory mapping is lost).